@@ -9,8 +9,8 @@
 #'   May be abbreviated.
 #' @param ... Currently not used.
 #'
-#' @return Invisibly returns the p-value of the test statistics. A p-value
-#' < 0.05 indicates a significant deviation from normal distribution
+#' @return The p-value of the test statistics. A p-value < 0.05 indicates a
+#'   significant deviation from normal distribution.
 #'
 #' @note For mixed-effects models, studentized residuals, and *not*
 #'   standardized residuals, are used for the test. There is also a
@@ -18,11 +18,11 @@
 #'    implemented in the
 #'   \href{https://easystats.github.io/see/}{\pkg{see}-package}.
 #'
-#' @details `check_normality()` calls `stats::shapiro.test`
-#' and checks the standardized residuals (or Studentized residuals for mixed
-#' models) for normal distribution. Note that this formal test almost always
-#' yields significant results for the distribution of residuals and visual
-#' inspection (e.g. Q-Q plots) are preferable.
+#' @details `check_normality()` calls `stats::shapiro.test` and checks the
+#' standardized residuals (or Studentized residuals for mixed models) for
+#' normal distribution. Note that this formal test almost always yields
+#' significant results for the distribution of residuals and visual inspection
+#' (e.g. Q-Q plots) are preferable.
 #'
 #' @examples
 #' m <<- lm(mpg ~ wt + cyl + gear + disp, data = mtcars)
@@ -46,11 +46,18 @@ check_normality <- function(x, ...) {
 }
 
 
+
+# default -------------------------
+
 #' @export
 check_normality.default <- function(x, ...) {
-  # valid model?
+  # check for valid input
+  .is_model_valid(x)
+
   if (!insight::model_info(x)$is_linear) {
-    message(insight::format_message("Checking normality of residuals is only useful an appropriate assumption for linear models."))
+    insight::format_alert(
+      "Checking normality of residuals is only useful an appropriate assumption for linear models."
+    )
     return(NULL)
   }
 
@@ -58,16 +65,89 @@ check_normality.default <- function(x, ...) {
   p.val <- .check_normality(stats::rstandard(x), x)
 
   attr(p.val, "data") <- x
-  attr(p.val, "object_name") <- .safe_deparse(substitute(x))
+  attr(p.val, "object_name") <- insight::safe_deparse_symbol(substitute(x))
   attr(p.val, "effects") <- "fixed"
   class(p.val) <- unique(c("check_normality", "see_check_normality", class(p.val)))
 
-  invisible(p.val)
+  p.val
+}
+
+# numeric -------------------
+
+#' @export
+check_normality.numeric <- function(x, ...) {
+  # check for normality of residuals
+  p.val <- .check_normality(x, NULL, type = "raw")
+
+  attr(p.val, "data") <- x
+  attr(p.val, "object_name") <- insight::safe_deparse(substitute(x))
+  attr(p.val, "effects") <- "fixed"
+  class(p.val) <- unique(c("check_normality", "see_check_normality", "check_normality_numeric", class(p.val)))
+
+  p.val
+}
+
+
+# methods ----------------------
+
+
+#' @importFrom stats residuals
+#' @export
+residuals.check_normality_numeric <- function(object, ...) {
+  attr(object, "data")
+}
+
+
+#' @importFrom stats rstudent
+#' @export
+rstudent.check_normality_numeric <- function(model, ...) {
+  attr(model, "data")
+}
+
+
+#' @export
+plot.check_normality <- function(x, ...) {
+  insight::check_if_installed("see", "for residual plots")
+  NextMethod()
+}
+
+
+#' @export
+print.check_normality <- function(x, ...) {
+  pstring <- insight::format_p(x)
+  type <- attributes(x)$type
+
+  if (identical(attributes(x)$effects, "random")) {
+    re_groups <- attributes(x)$re_groups
+    for (i in seq_along(x)) {
+      if (x[i] < 0.05) {
+        insight::print_color(
+          sprintf("Warning: Non-normality for random effects '%s' detected (%s).\n", re_groups[i], pstring[i]),
+          "red"
+        )
+      } else {
+        insight::print_color(
+          sprintf("OK: Random effects '%s' appear as normally distributed (%s).\n", re_groups[i], pstring[i]),
+          "green"
+        )
+      }
+    }
+  } else {
+    if (length(x) > 1 && "units" %in% names(attributes(x))) type <- attributes(x)$units
+    for (i in seq_along(x)) {
+      if (x[i] < 0.05) {
+        insight::print_color(sprintf("Warning: Non-normality of %s detected (%s).\n", type[i], pstring[i]), "red")
+      } else {
+        insight::print_color(sprintf("OK: %s appear as normally distributed (%s).\n", type[i], pstring[i]), "green")
+      }
+    }
+  }
+  invisible(x)
 }
 
 
 
-
+# other classes --------------------
 
 # mixed models ---------------------
 
@@ -79,8 +159,10 @@ check_normality.merMod <- function(x, effects = c("fixed", "random"), ...) {
   info <- insight::model_info(x)
 
   # valid model?
-  if (!info$is_linear) {
-    message(insight::format_message("Checking normality of residuals is only useful an appropriate assumption for linear models."))
+  if (!info$is_linear && effects == "fixed") {
+    insight::format_alert(
+      "Checking normality of residuals is only useful an appropriate assumption for linear models."
+    )
     return(NULL)
   }
 
@@ -102,19 +184,18 @@ check_normality.merMod <- function(x, effects = c("fixed", "random"), ...) {
       }
     )
 
-    p.val <- c()
-    re_len <- max(nchar(unlist(lapply(re, colnames))))
+    p.val <- re_groups <- NULL
 
     if (!is.null(re)) {
       for (i in names(re)) {
-        insight::print_color(sprintf("Group: %s\n", i), "blue")
         for (j in colnames(re[[i]])) {
-          cat(sprintf("%*s ", re_len, j))
+          re_groups <- c(re_groups, paste0(i, ": ", j))
           p.val <- c(p.val, .check_normality(re[[i]][[j]], x, "random effects"))
         }
-        cat("\n")
       }
-      attr(p.val, "re_qq") <- .diag_reqq(x, level = .95, model_info = info)
+      attr(p.val, "re_qq") <- .diag_reqq(x, level = 0.95, model_info = info)
+      attr(p.val, "type") <- "random effects"
+      attr(p.val, "re_groups") <- re_groups
     }
   } else {
     # check for normality of residuals
@@ -122,11 +203,11 @@ check_normality.merMod <- function(x, effects = c("fixed", "random"), ...) {
   }
 
   attr(p.val, "data") <- x
-  attr(p.val, "object_name") <- .safe_deparse(substitute(x))
+  attr(p.val, "object_name") <- insight::safe_deparse_symbol(substitute(x))
   attr(p.val, "effects") <- effects
   class(p.val) <- unique(c("check_normality", "see_check_normality", class(p.val)))
 
-  invisible(p.val)
+  p.val
 }
 
 
@@ -144,17 +225,20 @@ check_normality.afex_aov <- function(x, ...) {
   p.val <- .check_normality(r, x)
 
   attr(p.val, "data") <- x
-  attr(p.val, "object_name") <- .safe_deparse(substitute(x))
+  attr(p.val, "object_name") <- insight::safe_deparse_symbol(substitute(x))
   class(p.val) <- unique(c("check_normality", "see_check_normality", class(p.val)))
 
   invisible(p.val)
 }
 
 
+#' @export
+check_normality.BFBayesFactor <- check_normality.afex_aov
+
+
 
 # helper ---------------------
 
-
 .check_normality <- function(x, model, type = "residuals") {
   ts <- tryCatch(
     {
@@ -170,19 +254,15 @@ check_normality.afex_aov <- function(x, ...) {
   )
 
   if (is.null(ts)) {
-    insight::print_color(sprintf("'check_normality()' does not support models of class '%s'.\n", class(model)[1]), "red")
+    insight::print_color(
+      sprintf("`check_normality()` does not support models of class `%s`.\n", class(model)[1]),
+      "red"
+    )
     return(NULL)
   }
 
-  # format p-value
-  p.val <- ts$p.value
-  pstring <- insight::format_p(p.val)
+  out <- ts$p.value
+  attr(out, "type") <- type
 
-  if (p.val < 0.05) {
-    insight::print_color(sprintf("Warning: Non-normality of %s detected (%s).\n", type, pstring), "red")
-  } else {
-    insight::print_color(sprintf("OK: %s appear as normally distributed (%s).\n", type, pstring), "green")
-  }
-
-  p.val
+  out
 }
