@@ -24,7 +24,9 @@ looic <- function(model, verbose = TRUE) {
 
   if (algorithm$algorithm != "sampling") {
     if (verbose) {
-      warning(insight::format_message("`looic()` only available for models fit using the 'sampling' algorithm."), call. = FALSE)
+      warning(insight::format_message(
+        "`looic()` only available for models fit using the 'sampling' algorithm."
+      ), call. = FALSE)
     }
     return(NA)
   }
@@ -61,6 +63,9 @@ looic <- function(model, verbose = TRUE) {
 }
 
 
+
+# methods --------------------------
+
 #' @export
 as.data.frame.looic <- function(x, row.names = NULL, ...) {
   data.frame(
@@ -73,3 +78,21 @@ as.data.frame.looic <- function(x, row.names = NULL, ...) {
     ...
   )
 }
+
+
+#' @export
+print.looic <- function(x, digits = 2, ...) {
+  insight::print_color("# LOOIC and ELPD with Standard Error\n\n", "blue")
+
+  out <- paste0(
+    c(
+      sprintf("  LOOIC: %.*f [%.*f]", digits, x$LOOIC, digits, x$LOOIC_SE),
+      sprintf("   ELPD: %.*f [%.*f]", digits, x$ELPD, digits, x$ELPD_SE)
+    ),
+    collapse = "\n"
+  )
+
+  cat(out)
+  cat("\n")
+  invisible(x)
+}
