@@ -5,6 +5,7 @@
 #'   from a model with binary or count outcome.
 #'
 #' @param model Model with binary or count outcome.
+#' @param ... Arguments from other functions, usually only used internally.
 #' @inheritParams model_performance.lm
 #'
 #' @return A list with three elements, the logarithmic, quadratic/Brier and spherical score.
@@ -15,17 +16,21 @@
 #' in the interval `[0, 1]`, with values closer to 1 indicating a more
 #' accurate model, and the logarithmic rule in the interval `[-Inf, 0]`,
 #' with values closer to 0 indicating a more accurate model.
-#' \cr \cr
+#'
 #' For `stan_lmer()` and `stan_glmer()` models, the predicted values
 #' are based on `posterior_predict()`, instead of `predict()`. Thus,
 #' results may differ more than expected from their non-Bayesian counterparts
 #' in **lme4**.
 #'
-#' @references Carvalho, A. (2016). An overview of applications of proper scoring rules. Decision Analysis 13, 223–242. \doi{10.1287/deca.2016.0337}
+#' @references
+#' Carvalho, A. (2016). An overview of applications of proper scoring rules.
+#' Decision Analysis 13, 223–242. \doi{10.1287/deca.2016.0337}
 #'
-#' @note Code is partially based on [GLMMadaptive::scoring_rules()](https://drizopoulos.github.io/GLMMadaptive/reference/scoring_rules.html).
+#' @note
+#' Code is partially based on
+#' [GLMMadaptive::scoring_rules()](https://drizopoulos.github.io/GLMMadaptive/reference/scoring_rules.html).
 #'
-#' @seealso [`performance_logloss()`][performance_logloss]
+#' @seealso [`performance_logloss()`]
 #'
 #' @examples
 #' ## Dobson (1990) Page 93: Randomized Controlled Trial :
@@ -40,7 +45,7 @@
 #'   data(Salamanders)
 #'   model <- glmmTMB(
 #'     count ~ spp + mined + (1 | site),
-#'     zi =  ~ spp + mined,
+#'     zi = ~ spp + mined,
 #'     family = nbinom2(),
 #'     data = Salamanders
 #'   )
@@ -49,13 +54,15 @@
 #' }
 #' }
 #' @export
-performance_score <- function(model, verbose = TRUE) {
+performance_score <- function(model, verbose = TRUE, ...) {
   # check special case
   if (inherits(model, c("logitor", "logitmfx", "probitmfx", "negbinirr", "negbinmfx", "poissonirr", "poissonmfx"))) {
     model <- model$fit
   }
 
-  minfo <- insight::model_info(model, verbose = verbose)
+  if (is.null(minfo <- list(...)$model_info)) {
+    minfo <- suppressWarnings(insight::model_info(model, verbose = FALSE))
+  }
 
   if (minfo$is_ordinal || minfo$is_multinomial) {
     if (verbose) insight::print_color("Can't calculate proper scoring rules for ordinal, multinomial or cumulative link models.\n", "red")
@@ -112,7 +119,7 @@ performance_score <- function(model, verbose = TRUE) {
   resp <- if (minfo$is_binomial) {
     .recode_to_zero(resp)
   } else {
-    .factor_to_numeric(resp)
+    datawizard::to_numeric(resp, dummy_factors = FALSE, preserve_levels = TRUE)
   }
   p_y <- prob_fun(resp, mean = pr$pred, pis = pr$pred_zi, sum(resp))
 
@@ -130,6 +137,46 @@ performance_score <- function(model, verbose = TRUE) {
 
 
 
+# methods -----------------------------------
+
+#' @export
+as.data.frame.performance_score <- function(x, row.names = NULL, ...) {
+  data.frame(
+    logarithmic = x$logarithmic,
+    quadratic = x$quadratic,
+    spherical = x$spherical,
+    stringsAsFactors = FALSE,
+    row.names = row.names,
+    ...
+  )
+}
+
+
+#' @export
+print.performance_score <- function(x, ...) {
+  # headline
+  insight::print_color("# Proper Scoring Rules\n\n", "blue")
+
+  results <- format(
+    c(
+      sprintf("%.4f", x$logarithmic),
+      sprintf("%.4f", x$quadratic),
+      sprintf("%.4f", x$spherical)
+    ),
+    justify = "right"
+  )
+
+  cat(sprintf("logarithmic: %s\n", results[1]))
+  cat(sprintf("  quadratic: %s\n", results[2]))
+  cat(sprintf("  spherical: %s\n", results[3]))
+
+  invisible(x)
+}
+
+
+
+# utilities ---------------------------------
+
 .dispersion_parameter <- function(model, minfo) {
   if (inherits(model, "MixMod")) {
     model$phis
@@ -185,16 +232,3 @@ performance_score <- function(model, verbose = TRUE) {
 
   list(pred = pred, pred_zi = pred_zi)
 }
-
-
-#' @export
-as.data.frame.performance_score <- function(x, row.names = NULL, ...) {
-  data.frame(
-    logarithmic = x$logarithmic,
-    quadratic = x$quadratic,
-    spherical = x$spherical,
-    stringsAsFactors = FALSE,
-    row.names = row.names,
-    ...
-  )
-}
