@@ -6,42 +6,41 @@
 #'   R2, pseudo-R2, or marginal / adjusted R2 values are returned.
 #'
 #' @param model A statistical model.
-#' @param ci Confidence Interval (CI) level. Default is \code{NULL}. Confidence
-#'   intervals for R2 can be calculated based on different methods, see
-#'   \code{ci_method}.
-#' @param ci_method Method for constructing the R2 confidence interval.
-#'   Options are \code{"analytical"} for sampling-theory-based frequentist
-#'   intervals and \code{"bootstrap"} for bootstrap intervals. Analytical intervals
-#'   are not available for all models. For Bayesian models, [r2_bayes()] is used.
-#' @param verbose Logical. Should details about R2 and CI methods be given (`TRUE`) or not (`FALSE`)?
+#' @param verbose Logical. Should details about R2 and CI methods be given
+#' (`TRUE`) or not (`FALSE`)?
+#' @param ci Confidence interval level, as scalar. If `NULL` (default), no
+#' confidence intervals for R2 are calculated.
 #' @param ... Arguments passed down to the related r2-methods.
 #' @inheritParams r2_nakagawa
 #'
 #' @return Returns a list containing values related to the most appropriate R2
 #'   for the given model (or `NULL` if no R2 could be extracted). See the
 #'   list below:
-#' \itemize{
-#'   \item Logistic models: [Tjur's R2][r2_tjur]
-#'   \item General linear models: [Nagelkerke's R2][r2_nagelkerke]
-#'   \item Multinomial Logit: [McFadden's R2][r2_mcfadden]
-#'   \item Models with zero-inflation: [R2 for zero-inflated models][r2_zeroinflated]
-#'   \item Mixed models: [Nakagawa's R2][r2_nakagawa]
-#'   \item Bayesian models: [R2 bayes][r2_bayes]
-#' }
+#'   - Logistic models: [Tjur's R2][r2_tjur]
+#'   - General linear models: [Nagelkerke's R2][r2_nagelkerke]
+#'   - Multinomial Logit: [McFadden's R2][r2_mcfadden]
+#'   - Models with zero-inflation: [R2 for zero-inflated models][r2_zeroinflated]
+#'   - Mixed models: [Nakagawa's R2][r2_nakagawa]
+#'   - Bayesian models: [R2 bayes][r2_bayes]
 #'
 #' @note If there is no `r2()`-method defined for the given model class,
-#'   `r2()` tries to return a "generic r2 value, calculated as following:
+#'   `r2()` tries to return a "generic" r-quared value, calculated as following:
 #'   `1-sum((y-y_hat)^2)/sum((y-y_bar)^2))`
 #'
-#' @seealso [r2_bayes()], [r2_coxsnell()], [r2_kullback()],
-#'   [r2_loo()], [r2_mcfadden()], [r2_nagelkerke()],
-#'   [r2_nakagawa()], [r2_tjur()], [r2_xu()] and
-#'   [r2_zeroinflated()].
+#' @seealso [`r2_bayes()`], [`r2_coxsnell()`], [`r2_kullback()`],
+#'   [`r2_loo()`], [`r2_mcfadden()`], [`r2_nagelkerke()`],
+#'   [`r2_nakagawa()`], [`r2_tjur()`], [`r2_xu()`] and
+#'   [`r2_zeroinflated()`].
 #'
 #' @examples
+#' # Pseudo r-quared for GLM
 #' model <- glm(vs ~ wt + mpg, data = mtcars, family = "binomial")
 #' r2(model)
 #'
+#' # r-squared including confidence intervals
+#' model <- lm(mpg ~ wt + hp, data = mtcars)
+#' r2(model, ci = 0.95)
+#'
 #' if (require("lme4")) {
 #'   model <- lmer(Sepal.Length ~ Petal.Length + (1 | Species), data = iris)
 #'   r2(model)
@@ -59,21 +58,33 @@ r2 <- function(model, ...) {
 
 #' @rdname r2
 #' @export
-r2.default <- function(model, ci = NULL, ci_method = "analytical", verbose = TRUE, ...) {
-  ci_method <- match.arg(ci_method, choices = c("analytical", "bootstrap"))
+r2.default <- function(model, ci = NULL, verbose = TRUE, ...) {
+  # CI has own function
+  if (!is.null(ci) && !is.na(ci)) {
+    return(.r2_ci(model, ci = ci, verbose = verbose, ...))
+  }
 
+  if (is.null(minfo <- list(...)$model_info)) {
+    minfo <- suppressWarnings(insight::model_info(model, verbose = FALSE))
+  }
+
+  ## TODO: implement bootstrapped CIs later?
   # check input
-  ci <- .check_r2_ci_args(ci, ci_method, "bootstrap", verbose)
+  # ci <- .check_r2_ci_args(ci, ci_method, "bootstrap", verbose)
 
   out <- tryCatch(
     {
-      if (insight::model_info(model)$is_binomial) {
+      if (minfo$is_binomial) {
         resp <- .recode_to_zero(insight::get_response(model, verbose = FALSE))
       } else {
-        resp <- .factor_to_numeric(insight::get_response(model, verbose = FALSE))
+        resp <- datawizard::to_numeric(
+          insight::get_response(model, verbose = FALSE),
+          dummy_factors = FALSE,
+          preserve_levels = TRUE
+        )
       }
       mean_resp <- mean(resp, na.rm = TRUE)
-      pred <- insight::get_predicted(model, verbose = FALSE)
+      pred <- insight::get_predicted(model, ci = NULL, verbose = FALSE)
       list(R2 = 1 - sum((resp - pred)^2) / sum((resp - mean_resp)^2))
     },
     error = function(e) {
@@ -82,7 +93,7 @@ r2.default <- function(model, ci = NULL, ci_method = "analytical", verbose = TRU
   )
 
   if (is.null(out) && isTRUE(verbose)) {
-    insight::print_color(sprintf("'r2()' does not support models of class '%s'.\n", class(model)[1]), "red")
+    insight::print_color(sprintf("`r2()` does not support models of class `%s`.\n", class(model)[1]), "red")
   }
 
   if (!is.null(out)) {
@@ -95,12 +106,15 @@ r2.default <- function(model, ci = NULL, ci_method = "analytical", verbose = TRU
 
 
 #' @export
-r2.lm <- function(model, ...) {
+r2.lm <- function(model, ci = NULL, ...) {
+  if (!is.null(ci) && !is.na(ci)) {
+    return(.r2_ci(model, ci = ci, ...))
+  }
   .r2_lm(summary(model))
 }
 
 
-.r2_lm <- function(model_summary) {
+.r2_lm <- function(model_summary, ci = NULL) {
   out <- list(
     R2 = model_summary$r.squared,
     R2_adjusted = model_summary$adj.r.squared
@@ -127,7 +141,10 @@ r2.lm <- function(model, ...) {
 
 
 #' @export
-r2.summary.lm <- function(model, ...) {
+r2.summary.lm <- function(model, ci = NULL, ...) {
+  if (!is.null(ci) && !is.na(ci)) {
+    return(.r2_ci(model, ci = ci, ...))
+  }
   .r2_lm(model)
 }
 
@@ -152,6 +169,24 @@ r2.systemfit <- function(model, ...) {
 }
 
 
+#' @export
+r2.lm_robust <- function(model, ...) {
+  out <- list(
+    "R2" = tryCatch(
+      model[["r.squared"]],
+      error = function(e) NULL
+    ),
+    "R2_adjusted" = tryCatch(
+      model[["adj.r.squared"]],
+      error = function(e) NULL
+    )
+  )
+  names(out$R2) <- "R2"
+  names(out$R2_adjusted) <- "adjusted R2"
+  attr(out, "model_type") <- "Linear"
+  structure(class = "r2_generic", out)
+}
+
 
 #' @export
 r2.ols <- function(model, ...) {
@@ -162,6 +197,8 @@ r2.ols <- function(model, ...) {
   structure(class = "r2_generic", out)
 }
 
+
+
 #' @export
 r2.lrm <- r2.ols
 
@@ -194,7 +231,11 @@ r2.mhurdle <- function(model, ...) {
 
 
 #' @export
-r2.aov <- function(model, ...) {
+r2.aov <- function(model, ci = NULL, ...) {
+  if (!is.null(ci) && !is.na(ci)) {
+    return(.r2_ci(model, ci = ci, ...))
+  }
+
   model_summary <- stats::summary.lm(model)
 
   out <- list(
@@ -219,7 +260,7 @@ r2.mlm <- function(model, ...) {
     tmp <- list(
       R2 = model_summary[[i]]$r.squared,
       R2_adjusted = model_summary[[i]]$adj.r.squared,
-      Response = sub("Response ", "", i)
+      Response = sub("Response ", "", i, fixed = TRUE)
     )
     names(tmp$R2) <- "R2"
     names(tmp$R2_adjusted) <- "adjusted R2"
@@ -236,23 +277,29 @@ r2.mlm <- function(model, ...) {
 
 
 #' @export
-r2.glm <- function(model, verbose = TRUE, ...) {
-  info <- insight::model_info(model)
+r2.glm <- function(model, ci = NULL, verbose = TRUE, ...) {
+  if (!is.null(ci) && !is.na(ci)) {
+    return(.r2_ci(model, ci = ci, verbose = verbose, ...))
+  }
+
+  if (is.null(info <- list(...)$model_info)) {
+    info <- suppressWarnings(insight::model_info(model, verbose = FALSE))
+  }
 
   if (info$family %in% c("gaussian", "inverse.gaussian")) {
     out <- r2.default(model, ...)
   } else if (info$is_logit && info$is_bernoulli) {
-    out <- list("R2_Tjur" = r2_tjur(model))
+    out <- list("R2_Tjur" = r2_tjur(model, ...))
     attr(out, "model_type") <- "Logistic"
     names(out$R2_Tjur) <- "Tjur's R2"
     class(out) <- c("r2_pseudo", class(out))
   } else if (info$is_binomial && !info$is_bernoulli && class(model)[1] == "glm") {
     if (verbose) {
-      warning(insight::format_message("Can't calculate accurate R2 for binomial models that are not Bernoulli models."), call. = FALSE)
+      insight::format_warning("Can't calculate accurate R2 for binomial models that are not Bernoulli models.")
     }
     out <- NULL
   } else {
-    out <- list("R2_Nagelkerke" = r2_nagelkerke(model))
+    out <- list("R2_Nagelkerke" = r2_nagelkerke(model, ...))
     names(out$R2_Nagelkerke) <- "Nagelkerke's R2"
     attr(out, "model_type") <- "Generalized Linear"
     class(out) <- c("r2_pseudo", class(out))
@@ -347,9 +394,6 @@ r2.clm2 <- r2.censReg
 #' @export
 r2.coxph <- r2.censReg
 
-#' @export
-r2.multinom <- r2.censReg
-
 #' @export
 r2.mclogit <- r2.censReg
 
@@ -377,6 +421,20 @@ r2.bife <- r2.censReg
 
 
 
+# McFadden ----------------------
+
+
+#' @export
+r2.multinom <- function(model, ...) {
+  out <- r2_mcfadden(model)
+  class(out) <- c("r2_pseudo", class(out))
+  out
+}
+
+#' @export
+r2.mlogit <- r2.multinom
+
+
 
 
 # Zeroinflated R2 ------------------
@@ -399,8 +457,8 @@ r2.zeroinfl <- r2.hurdle
 
 #' @rdname r2
 #' @export
-r2.merMod <- function(model, tolerance = 1e-5, ...) {
-  r2_nakagawa(model, tolerance = tolerance, ...)
+r2.merMod <- function(model, ci = NULL, tolerance = 1e-5, ...) {
+  r2_nakagawa(model, ci = ci, tolerance = tolerance, ...)
 }
 
 #' @export
@@ -495,7 +553,6 @@ r2.BFBayesFactor <- r2.brmsfit
 
 #' @export
 r2.gam <- function(model, ...) {
-
   # gamlss inherits from gam, and summary.gamlss prints results automatically
   printout <- utils::capture.output(s <- summary(model))
 
@@ -555,14 +612,14 @@ r2.fixest <- function(model, ...) {
 
   r2 <- fixest::r2(model)
 
-  out_normal <- .compact_list(list(
+  out_normal <- insight::compact_list(list(
     R2 = r2["r2"],
     R2_adjusted = r2["ar2"],
     R2_within = r2["wr2"],
     R2_within_adjusted = r2["war2"]
   ), remove_na = TRUE)
 
-  out_pseudo <- .compact_list(list(
+  out_pseudo <- insight::compact_list(list(
     R2 = r2["pr2"],
     R2_adjusted = r2["apr2"],
     R2_within = r2["wpr2"],
@@ -635,7 +692,7 @@ r2.bigglm <- function(model, ...) {
 
 #' @export
 r2.biglm <- function(model, ...) {
-  df.int <- ifelse(insight::has_intercept(model), 1, 0)
+  df.int <- as.numeric(insight::has_intercept(model))
   n <- suppressWarnings(insight::n_obs(model))
 
   rsq <- summary(model)$rsq
@@ -672,16 +729,6 @@ r2.complmrob <- r2.lmrob
 
 
 
-#' @export
-r2.mlogit <- function(model, ...) {
-  out <- list("R2_McFadden" = r2_mcfadden(model))
-  names(out$R2_McFadden) <- "McFadden's R2"
-  class(out) <- c("r2_pseudo", class(out))
-  out
-}
-
-
-
 #' @export
 r2.mmclogit <- function(model, ...) {
   list(R2 = NA)
@@ -699,7 +746,7 @@ r2.Arima <- function(model, ...) {
   if (!requireNamespace("forecast", quietly = TRUE)) {
     list(R2 = NA)
   } else {
-    list(R2 = stats::cor(stats::fitted(model), insight::get_data(model))^2)
+    list(R2 = stats::cor(stats::fitted(model), insight::get_data(model, verbose = FALSE))^2)
   }
 }
 
@@ -783,7 +830,9 @@ r2.DirichletRegModel <- function(model, ...) {
   if (!is.null(ci) && !is.na(ci)) {
     if (!is.null(valid_ci_method) && !ci_method %in% valid_ci_method) {
       if (verbose) {
-        warning(paste0("Method '", ci_method, "' to compute confidence intervals for R2 not supported."), call. = FALSE)
+        insight::format_warning(
+          paste0("Method `", ci_method, "` to compute confidence intervals for R2 not supported.")
+        )
       }
       return(NULL)
     }
