@@ -2,39 +2,35 @@
 #' @name r2_coxsnell
 #'
 #' @description
-#' Calculates the pseudo-R2 value based on the proposal from \cite{Cox & Snell
-#' (1989)}.
+#' Calculates the pseudo-R2 value based on the proposal from *Cox & Snell (1989)*.
 #'
 #' @param model Model with binary outcome.
 #' @param ... Currently not used.
 #'
 #' @details
-#' This index was proposed by \cite{Cox & Snell (1989, pp. 208-9)} and,
-#' apparently independently, by \cite{Magee (1990)}; but had been suggested
-#' earlier for binary response models by \cite{Maddala (1983)}. However, this
+#' This index was proposed by *Cox and Snell (1989, pp. 208-9)* and,
+#' apparently independently, by *Magee (1990)*; but had been suggested
+#' earlier for binary response models by *Maddala (1983)*. However, this
 #' index achieves a maximum of less than 1 for discrete models (i.e. models
 #' whose likelihood is a product of probabilities) which have a maximum of 1,
-#' instead of densities, which can become infinite \cite{(Nagelkerke, 1991)}.
+#' instead of densities, which can become infinite *(Nagelkerke, 1991)*.
 #'
 #' @return A named vector with the R2 value.
 #'
 #' @examples
 #' model <- glm(vs ~ wt + mpg, data = mtcars, family = "binomial")
 #' r2_coxsnell(model)
+#'
 #' @references
-#' \itemize{
-#'   \item Cox, D. R., Snell, E. J. (1989). Analysis of binary data (Vol. 32).
+#' - Cox, D. R., Snell, E. J. (1989). Analysis of binary data (Vol. 32).
 #'   Monographs on Statistics and Applied Probability.
-#'
-#'   \item Magee, L. (1990). R 2 measures based on Wald and likelihood ratio
+#' - Magee, L. (1990). R 2 measures based on Wald and likelihood ratio
 #'   joint significance tests. The American Statistician, 44(3), 250-253.
-#'
-#'   \item Maddala, G. S. (1986). Limited-dependent and qualitative variables in
+#' - Maddala, G. S. (1986). Limited-dependent and qualitative variables in
 #'   econometrics (No. 3). Cambridge university press.
-#'
-#'   \item Nagelkerke, N. J. (1991). A note on a general definition of the
+#' - Nagelkerke, N. J. (1991). A note on a general definition of the
 #'   coefficient of determination. Biometrika, 78(3), 691-692.
-#' }
+#'
 #' @export
 r2_coxsnell <- function(model, ...) {
   UseMethod("r2_coxsnell")
@@ -53,7 +49,7 @@ r2_coxsnell <- function(model, ...) {
     n <- suppressWarnings(insight::n_obs(model))
   } else {
     n <- attr(l_full, "nobs")
-    if (is.null(n)) n <- suppressWarnings(insight::n_obs(model))
+    if (is.null(n)) n <- suppressWarnings(insight::n_obs(model, disaggregate = TRUE))
   }
 
   r2_coxsnell <- as.vector(1 - exp(-G2 / n))
@@ -69,10 +65,12 @@ r2_coxsnell <- function(model, ...) {
 
 #' @export
 r2_coxsnell.glm <- function(model, verbose = TRUE, ...) {
-  info <- insight::model_info(model)
+  if (is.null(info <- list(...)$model_info)) {
+    info <- suppressWarnings(insight::model_info(model, verbose = FALSE))
+  }
   if (info$is_binomial && !info$is_bernoulli && class(model)[1] == "glm") {
     if (verbose) {
-      warning(insight::format_message("Can't calculate accurate R2 for binomial models that are not Bernoulli models."), call. = FALSE)
+      insight::format_warning("Can't calculate accurate R2 for binomial models that are not Bernoulli models.")
     }
     return(NULL)
   } else {
@@ -80,7 +78,7 @@ r2_coxsnell.glm <- function(model, verbose = TRUE, ...) {
     if (is.null(model$deviance)) {
       return(NULL)
     }
-    r2_coxsnell <- (1 - exp((model$deviance - model$null.deviance) / insight::n_obs(model)))
+    r2_coxsnell <- (1 - exp((model$deviance - model$null.deviance) / insight::n_obs(model, disaggregate = TRUE)))
     names(r2_coxsnell) <- "Cox & Snell's R2"
     r2_coxsnell
   }
