@@ -1,6 +1,4 @@
-if (require("testthat") && require("performance") && require("glmmTMB")) {
-  context("check_overdispersion")
-
+if (requiet("glmmTMB") && getRversion() >= "4.0.0") {
   data(Salamanders)
 
   m1 <- glm(count ~ spp + mined, family = poisson, data = Salamanders)
@@ -21,7 +19,8 @@ if (require("testthat") && require("performance") && require("glmmTMB")) {
           residual_df = 636L,
           p_value = 3.26607509162498e-122
         ),
-        class = "check_overdisp"
+        class = c("check_overdisp", "see_check_overdisp"),
+        object_name = "m1"
       ),
       tolerance = 1e-3
     )
@@ -37,7 +36,8 @@ if (require("testthat") && require("performance") && require("glmmTMB")) {
           residual_df = 635L,
           p_value = 8.41489530177729e-69
         ),
-        class = "check_overdisp"
+        class = c("check_overdisp", "see_check_overdisp"),
+        object_name = "m2"
       ),
       tolerance = 1e-3
     )
