@@ -1,4 +1,4 @@
-if (requiet("testthat") && requiet("performance") && requiet("glmmTMB") && requiet("lme4")) {
+if (requiet("glmmTMB") && requiet("lme4")) {
   set.seed(123)
   data(Salamanders)
   m <- glm(count ~ spp + mined, family = poisson, data = Salamanders)
@@ -29,14 +29,16 @@ if (requiet("testthat") && requiet("performance") && requiet("glmmTMB") && requi
     )
     mu <- 5 * (-4 + with(dd, as.integer(f1) + 4 * as.numeric(f2)))
     dd$y <- rnbinom(nrow(dd), mu = mu, size = 0.5)
-    m <- glmer.nb(y ~ f1 * f2 + (1 | g), data = dd, verbose = FALSE)
+    dat2 <<- dd
+    m <- glmer.nb(y ~ f1 * f2 + (1 | g), data = dat2, verbose = FALSE)
 
     expect_equal(check_zeroinflation(m),
-      structure(list(
-        predicted.zeros = 153, observed.zeros = 155L,
-        ratio = 0.987096774193548, tolerance = 0.05
-      ),
-      class = "check_zi"
+      structure(
+        list(
+          predicted.zeros = 153, observed.zeros = 155L,
+          ratio = 0.987096774193548, tolerance = 0.05
+        ),
+        class = "check_zi"
       ),
       tolerance = 1e-3
     )
